<?php

if( ! defined( 'ABSPATH' ) ) exit(); // Exit if accessed directly

/**
 * HT Cf7 Admin
*/
class Extensions_Cf7_Admin_Setting
{
    private $extcf7_layout_instance;

	function __construct($extcf7_layout_instance)
	{	
        $this->extcf7_layout_instance = $extcf7_layout_instance;
        add_action( 'admin_init', array( $this, 'admin_init' ) );
        add_action( 'admin_menu', array( $this, 'admin_menu' ) );
        add_action( 'admin_enqueue_scripts', array($this, 'extcf7_admin_assets') );
	}

	// Plugins menu Register
    function admin_menu() {
        add_menu_page(
			__('HT Cf7 Extension','cf7-extensions'),
			__('HT Cf7 Extension','cf7-extensions'),
			'manage_options',
			'contat-form-list',
			array($this,'extcf7_form_data_page'),
			'dashicons-media-text',
			55
		);

        add_submenu_page(
            'contat-form-list',
            __( 'Cf7 DB', 'cf7-extensions' ),
            __( 'Cf7 DB', 'cf7-extensions' ),
            'manage_options',
            'contat-form-list',
            array($this,'extcf7_form_data_page')
        );

        add_submenu_page(
            'contat-form-list',
            __( 'Cf7 Conditional', 'cf7-extensions' ),
            __( 'Cf7 Conditional', 'cf7-extensions' ),
            'manage_options',
            'cf7-conditional-settings',
            array($this,'extcf7_condition_page')
        );

         add_submenu_page(
            'contat-form-list',
            __( 'Cf7 Redirection', 'cf7-extensions' ),
            __( 'Cf7 Redirection', 'cf7-extensions' ),
            'manage_options',
            'cf7-redirection-settings',
            array($this,'extcf7_redirection_page')
        );

        add_submenu_page(
            'contat-form-list',
            __( 'Settings', 'cf7-extensions' ),
            __( 'Settings', 'cf7-extensions' ),
            'manage_options',
            'general-settings',
            array($this,'extcf7_general_settings')
        );

        add_submenu_page(
            'contat-form-list',
            __( 'Extensions', 'cf7-extensions' ),
            __( 'Extensions', 'cf7-extensions' ),
            'manage_options',
            'cf7-pro-features',
            array($this,'extcf7_extensions_page')
        );
    }

    function admin_init() {
        $conditional_settings_options=array(
            'conditional_mode',
            'animation_enable',
            'admimation_in_time',
            'admimation_out_time'
        );
        foreach ($conditional_settings_options as $conditional_field) {
            register_setting( 'conditional-settings-group', $conditional_field );
        }

        register_setting( 'redirection-setting', 'redirection_delay');

        $general_setting_options = array(
            'ip_address_enable',
            'reffer_link_enable'
        );

        foreach ($general_setting_options as $option) {
            register_setting( 'general-settings-group', $option );
        }
    }

    function extcf7_admin_assets($hook){
        if("toplevel_page_contat-form-list" === $hook || 'toplevel_page_wpcf7' === $hook || "ht-cf7-extension_page_cf7-conditional-settings" === $hook || 'ht-cf7-extension_page_general-settings' === $hook || 'ht-cf7-extension_page_cf7-pro-features' === $hook){
            wp_enqueue_style( 'ht-cf7-admin-style', CF7_EXTENTIONS_PL_URL.'admin/assets/css/admin-style.css','',time());
            wp_enqueue_script( 'ht-cf7-admin-script', CF7_EXTENTIONS_PL_URL.'admin/assets/js/admin.js', array('jquery'), time(), true);
            $localize_animation_data = [
                'animitation_status' => get_option('animation_enable')?get_option('animation_enable'):'on',
            ];
            wp_localize_script( 'ht-cf7-admin-script', 'extcf7_animation_info', $localize_animation_data);
        }

        if('toplevel_page_wpcf7' === $hook ){
            wp_enqueue_script( 'ht-cf7-conditional-script', CF7_EXTENTIONS_PL_URL.'admin/assets/js/conditional.js', array('jquery'), time(), true);
            wp_enqueue_script( 'ht-cf7-redirection-script', CF7_EXTENTIONS_PL_URL.'admin/assets/js/redirection.js', array('jquery'), time(), true);
            $localize_condition_mode_data=[
                'conditional_mode' => get_option('conditional_mode')?get_option('conditional_mode'):'normal',
            ];
            wp_localize_script( 'ht-cf7-conditional-script', 'extcf7_conditional_mode', $localize_condition_mode_data);
            $ajaxurl = "var ajaxurl='".admin_url( 'admin-ajax.php')."'";
            wp_add_inline_script('ht-cf7-conditional-script',$ajaxurl);

            wp_enqueue_script( 'ht-cf7-mailchimp-map-script', CF7_EXTENTIONS_PL_URL.'admin/assets/js/mailchimp-map.js', array('jquery'), time(), true);
        }

        if("toplevel_page_contat-form-list" === $hook){
            wp_enqueue_style('jquery-datepicker-style', CF7_EXTENTIONS_PL_URL.'admin/assets/css/jquery-ui.css');
            wp_enqueue_script('jquery-ui-datepicker');
        }

    }

	function extcf7_form_data_page() {
       $layout_instance = $this->extcf7_layout_instance->get_layout_instance();
       if($layout_instance instanceof Extensions_Cf7_Form_Datalist_Render){
            echo $layout_instance->cf7_layout_render();
       }
    }

    function extcf7_condition_page(){
        echo '<h2>'.esc_html__( 'Conditional Field Options','cf7-extensions' ).'</h2>';
        echo '<form action="options.php" method="post">';
        settings_fields( 'conditional-settings-group' );
        do_settings_sections( 'cf7-conditional-settings' );
        require_once( CF7_EXTENTIONS_PL_PATH.'admin/template/conditional-setting.php');
        submit_button();
        echo '</form>';
    }	

    function extcf7_redirection_page(){
        echo '<h2>'.esc_html__( 'Redirection Setting','cf7-extensions' ).'</h2>';
        echo '<form action="options.php" method="post">';
        settings_fields( 'redirection-setting' );
        do_settings_sections( 'cf7-redirection-settings' );
        $redirection_delay = get_option('redirection_delay') ? get_option('redirection_delay') : '200';
        $link = admin_url().'admin.php?page=wpcf7';
        ?>
            <table class="form-table" role="presentation">
                <tbody>
                    <tr>
                        <th scope="row"><?php echo esc_html__('Redirection Delay','cf7-extensions');?></th>
                        <td>
                            <input type="text" class="regular-text" name="redirection_delay" value="<?php echo $redirection_delay; ?>">
                            <p><?php echo esc_html__('Input a positive integer value for the dalay of redirection. The values in milliseconds(Default:200)','cf7-extensions'); ?></p>
                        </td>
                    </tr>
                </tbody>
            </table>
            <div class="cf7-editor-link">
                <a href="<?php echo esc_url($link); ?>"><?php echo esc_html__('Go To Contact Form 7 Editor','cf7-extensions'); ?></a>
            </div>
        <?php
        submit_button();
        echo '</form>';
    }   

    function extcf7_general_settings(){
        echo '<h2>'.esc_html__( 'Settings','cf7-extensions' ).'</h2>';
        echo '<form action="options.php" class="extcf7_pro-from-wraper" method="post">';
        settings_fields( 'general-settings-group' );
        do_settings_sections( 'cf7-general-settings' );
        require_once( CF7_EXTENTIONS_PL_PATH.'admin/template/general-options-layout.php');
        submit_button();
        echo '</form>';
    }

    function extcf7_extensions_page(){
        echo '<h2>'.esc_html__( 'Extensions','cf7-extensions' ).'</h2>';
        require_once( CF7_EXTENTIONS_PL_PATH.'admin/template/pro-feature-list.php');
    }
}

$extcf7_layout_instance = new Extensions_Cf7_Layout_Instance();
new Extensions_Cf7_Admin_Setting($extcf7_layout_instance);

/**
 * HT Cf7 Form DB layout instance
*/
class Extensions_Cf7_Layout_Instance
{
    
    function get_layout_instance(){
        $cf7_id  = empty($_GET['cf7_id']) ? 0 : absint($_GET['cf7_id']);
        $cf7em_id = empty($_GET['cf7em_id']) ? 0 : absint($_GET['cf7em_id']);

        if ( !empty($cf7_id) && empty($cf7em_id) ) {
            return new Extensions_Cf7_Page();
        }else if(!empty($cf7_id) && !empty($cf7em_id)){
            return new Extensions_Cf7_Detail_Page();
        }else{
            return new Extensions_Cf7_Post_List();
        }
    }
}

